# MIN
* *min*imal manpages
* providing you with the 80/20 on how many bash utilities are used

[![demo](https://asciinema.org/a/XnrGtDVrAqIBQTH9xosKOCamf.png)](https://asciinema.org/a/XnrGtDVrAqIBQTH9xosKOCamf?autoplay=1)

# Installation
* available from pypi via `pip install miniman`

# Usage
* contains minpages for bash commands, as well as more general explainer pages for important topics in the unix workflow (e.g. file, filesystem)

## Bash commands
* run `min` to get a list of all available minpages for bash commands
* run `min command` to get the minpage for bash command `command`
* e.g. `min grep` to get the minpage for `grep`

## Unix Topics
* run `min -t` to get a list of all available minpages for unix topics
* run `min -t topic` to get the minpage for unix topic `topic`
* e.g. `min -t filesystem` to the minpage for `filesystem`
